Enum s3_server::dto::CreateBucketError
source · [−]Expand description
Errors returned by CreateBucket
Variants
BucketAlreadyExists(String)
The requested bucket name is not available. The bucket namespace is shared by all users of the system. Select a different name and try again.
BucketAlreadyOwnedByYou(String)
The bucket you tried to create already exists, and you own it. Amazon S3 returns this error in all AWS Regions except in the North Virginia Region. For legacy compatibility, if you re-create an existing bucket that you already own in the North Virginia Region, Amazon S3 returns 200 OK and resets the bucket access control lists (ACLs).
Implementations
sourceimpl CreateBucketError
impl CreateBucketError
pub fn from_response(
res: BufferedHttpResponse
) -> RusotoError<CreateBucketError>