pub struct AuthorizationV4<'a> {
    pub algorithm: &'a str,
    pub credential: CredentialV4<'a>,
    pub signed_headers: Vec<&'a str>,
    pub signature: &'a str,
}
Authorization

Fields

algorithm: &'a str

The algorithm that was used to calculate the signature.

credential: CredentialV4<'a>

Access key ID and the scope information, which includes the date, Region, and service that were used to calculate the signature.

signed_headers: Vec<&'a str>

A semicolon-separated list of request headers that you used to compute Signature.

signature: &'a str

The 256-bit signature expressed as 64 lowercase hexadecimal characters.

Implementations

parse AuthorizationV4 from Authorization header

Errors

Returns an Err if the header is invalid