pub struct CredentialV4<'a> {
    pub access_key_id: &'a str,
    pub date: &'a str,
    pub aws_region: &'a str,
    pub aws_service: &'a str,
}
Access key ID and the scope information, which includes the date, Region, and service that were used to calculate the signature.

This string has the following form: <your-access-key-id>/<date>/<aws-region>/<aws-service>/aws4_request

See sigv4-auth-using-authorization-header

Fields

access_key_id: &'a str

access key id

date: &'a str

value is specified using YYYYMMDD format.

aws_region: &'a str

region

aws_service: &'a str

value is s3 when sending request to Amazon S3.