Struct s3_server::headers::AuthorizationV4
source · [−]pub struct AuthorizationV4<'a> {
pub algorithm: &'a str,
pub credential: CredentialV4<'a>,
pub signed_headers: Vec<&'a str>,
pub signature: &'a str,
}Expand description
Authorization
Fields
algorithm: &'a strThe algorithm that was used to calculate the signature.
credential: CredentialV4<'a>Access key ID and the scope information, which includes the date, Region, and service that were used to calculate the signature.
signed_headers: Vec<&'a str>A semicolon-separated list of request headers that you used to compute Signature.
signature: &'a strThe 256-bit signature expressed as 64 lowercase hexadecimal characters.
Implementations
sourceimpl<'a> AuthorizationV4<'a>
impl<'a> AuthorizationV4<'a>
sourcepub fn from_header_str(auth: &'a str) -> Result<Self, ParseAuthorizationError>
pub fn from_header_str(auth: &'a str) -> Result<Self, ParseAuthorizationError>