Struct s3_server::headers::CredentialV4
source · [−]pub struct CredentialV4<'a> {
pub access_key_id: &'a str,
pub date: &'a str,
pub aws_region: &'a str,
pub aws_service: &'a str,
}Expand description
Access key ID and the scope information, which includes the date, Region, and service that were used to calculate the signature.
This string has the following form:
<your-access-key-id>/<date>/<aws-region>/<aws-service>/aws4_request
Fields
access_key_id: &'a straccess key id
date: &'a straws_region: &'a strregion
aws_service: &'a strs3 when sending request to Amazon S3.